<template>
  <div class="product-box">
    <!-- 头部导航栏 -->
    <van-nav-bar style="background-color: #528abe">
      <template #left>
        <div @click="pageBack" style="display: flex; align-items: center">
          <van-icon name="arrow-left" size="18" />
          <span>{{ $t("selectPage.index.TR") }}</span>
        </div>
      </template>
      <template #title>
        <label>入驻厂家</label>
      </template>
      <template #right>
        <!-- <van-icon name="search" size="18" /> -->
      </template>
    </van-nav-bar>

    <!-- 公司标题 -->
    <div style="width: 100%"></div>
    <!-- 显示内容 -->
    <div class="product-main">
      <van-cell
        v-for="item in m_showFactoryList"
        clickable
        is-link
        title-style="color:#000000 !important;margin-left:25px !important"
        :key="item.ID"
        :title="item.ShortName"
        @click="toSeriesDetailPump(item.ID)"
      >
        <template #icon>
          <van-image :src="item.LogoPath" width="100" height="50" />
        </template>
      </van-cell>
    </div>
  </div>
</template>

<script>
import languageMixin from "@/mixin/language";
export default {
  mixins: [languageMixin],
  data() {
    return {
      activeNames: "0", //默认打开的折叠面板
      m_Title: "",
      m_CatalogList: [], //类型列表
      m_FactoryList: [], //泵列表
      m_showFactoryList: [], //用于展示的泵列表

      m_selectCatalogName: "全部",
      m_Screen: "", //筛选
      m_catalogSelectValue: 0, //类型默认选择全部
      m_catalogSelectOption: [
        //类型选择列表
        { text: "全部", value: 0 },
      ],
    };
  },
  created() {},
  mounted() {
    let _this = this;
    _this.m_Title = _this.getSoftName();
    document.title = _this.m_Title;
    _this.getFactoryList();
  },
  methods: {
    //获取类型列表
    getFactoryList() {
      let _this = this;
      _this
        .$axios({
          methods: "get",
          url: _this.$globalConfig.WebApiUrl.MainUrl + "v1/Web/Corp/GetList",
          params: {
            lang: _this.getCurrentLanguageType(),
          },
        })
        .then(function (res) {
          //  console.log(res,"类型列表");
          let result = res.data;
          if (result.Code != 0) {
            return;
          }
          if (result.Data) {
            // console.log(result.Data,158)
            let factoryList = [];
            result.Data.forEach((element) => {
              let factoryNode = {
                Description: element.Description,
                FullName: element.FullName,
                ID: element.ID,
                LogoPath:
                  _this.$globalConfig.WebApiUrl.FileUrl + element.LogoPath,
                ShortName: element.ShortName,
              };
              factoryList.push(factoryNode);
            });
            _this.m_FactoryList = factoryList;
            _this.m_showFactoryList = JSON.parse(
              JSON.stringify(_this.m_FactoryList)
            );
          }
        })
        .catch(function (err) {
          console.log(err);
        });
    },

    toSeriesDetailPump(ID) {
      let query = { ID: ID };
      this.gotoPage("/Target/EBook/SeriesListLX", query, null);
      //   this.gotoPage("/EBook/SeriesDetailPump",query,null)
      // this.$router.push({
      //   path: `/${this.$getCurrentLanguageUrl()}/EBook/SeriesDetailPump`,
      //   query: { ID: ID },
      // });
    },
    //返回上一页
    pageBack() {
      this.gotoIndexPage();
    },
  },
};
</script>

<style lang="scss">
.product-box {
  background: #fafafa;
  width: 100%;
  height: 100vh;

  .van-dropdown-item__content {
    max-height: 34%;
  }
  .van-cell__title {
    text-align: start;
  }
  .van-collapse-item__content {
    padding: 0px 0px;
  }
  .product-main {
    width: 100%;
    height: calc(100% - 50px);
    overflow: auto;
    .van-cell {
      color: #528abe;
    }
    .van-cell__right-icon {
      color: #528abe;
    }
    .van-collapse-item__content {
      padding: 0px 0px;
    }
    .van-card__content {
      text-align: start;
      width: calc(100% - 88px);
    }
    .van-card__title {
      font-size: 14px;
      font-weight: 600;
    }
    .van-card {
      padding: 0px 0px;
      width: 100%;
      background-color: #ffffff;
    }
    .van-cell {
      padding: 0px 16px;
    }
    .van-card__desc {
      color: #aaaaaa;
      width: 235px;
      height: 50px;
    }
    .van-cell {
      color: #528abe;
    }
    .van-cell__right-icon {
      color: #006782;
    }
    .van-cell {
      padding: 10px 16px !important;
      align-items: center;
    }
    .van-cell-group__title {
      padding: 7px 16px 7px !important;
      text-align: left;
      background: #aaaaaa;
      font-weight: 600;
      color: #000000;
    }
    .van-cell__title,
    .van-cell__value {
      text-align: left;
      font-size: 13px;
      color: #36489e;
      font-weight: 600;
    }
 
  }
}
</style>